# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from youtube_ti.models.search_list_response import SearchListResponse

from youtube_ti.api_client import ApiClient, RequestSerialized
from youtube_ti.api_response import ApiResponse
from youtube_ti.rest import RESTResponseType


class SearchApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def youtube_search_list(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies a comma-separated list of one or more search resource properties that the API response will include. Set the parameter value to snippet.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        channel_id: Annotated[Optional[StrictStr], Field(description="Filter on resources belonging to this channelId.")] = None,
        channel_type: Annotated[Optional[StrictStr], Field(description="Add a filter on the channel search.")] = None,
        event_type: Annotated[Optional[StrictStr], Field(description="Filter on the livestream status of the videos.")] = None,
        for_content_owner: Annotated[Optional[StrictBool], Field(description="Search owned by a content owner.")] = None,
        for_developer: Annotated[Optional[StrictBool], Field(description="Restrict the search to only retrieve videos uploaded using the project id of the authenticated user.")] = None,
        for_mine: Annotated[Optional[StrictBool], Field(description="Search for the private videos of the authenticated user.")] = None,
        location: Annotated[Optional[StrictStr], Field(description="Filter on location of the video")] = None,
        location_radius: Annotated[Optional[StrictStr], Field(description="Filter on distance from the location (specified above).")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=0)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        order: Annotated[Optional[StrictStr], Field(description="Sort order of the results.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.")] = None,
        published_after: Annotated[Optional[StrictStr], Field(description="Filter on resources published after this date.")] = None,
        published_before: Annotated[Optional[StrictStr], Field(description="Filter on resources published before this date.")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Textual search terms to match.")] = None,
        region_code: Annotated[Optional[StrictStr], Field(description="Display the content as seen by viewers in this country.")] = None,
        relevance_language: Annotated[Optional[StrictStr], Field(description="Return results relevant to this language.")] = None,
        safe_search: Annotated[Optional[StrictStr], Field(description="Indicates whether the search results should include restricted content as well as standard content.")] = None,
        topic_id: Annotated[Optional[StrictStr], Field(description="Restrict results to a particular topic.")] = None,
        type: Annotated[Optional[List[StrictStr]], Field(description="Restrict results to a particular set of resource types from One Platform.")] = None,
        video_caption: Annotated[Optional[StrictStr], Field(description="Filter on the presence of captions on the videos.")] = None,
        video_category_id: Annotated[Optional[StrictStr], Field(description="Filter on videos in a specific category.")] = None,
        video_definition: Annotated[Optional[StrictStr], Field(description="Filter on the definition of the videos.")] = None,
        video_dimension: Annotated[Optional[StrictStr], Field(description="Filter on 3d videos.")] = None,
        video_duration: Annotated[Optional[StrictStr], Field(description="Filter on the duration of the videos.")] = None,
        video_embeddable: Annotated[Optional[StrictStr], Field(description="Filter on embeddable videos.")] = None,
        video_license: Annotated[Optional[StrictStr], Field(description="Filter on the license of the videos.")] = None,
        video_paid_product_placement: Optional[StrictStr] = None,
        video_syndicated: Annotated[Optional[StrictStr], Field(description="Filter on syndicated videos.")] = None,
        video_type: Annotated[Optional[StrictStr], Field(description="Filter on videos of a specific type.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> SearchListResponse:
        """youtube_search_list

        Retrieves a list of search resources

        :param part: The *part* parameter specifies a comma-separated list of one or more search resource properties that the API response will include. Set the parameter value to snippet. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param channel_id: Filter on resources belonging to this channelId.
        :type channel_id: str
        :param channel_type: Add a filter on the channel search.
        :type channel_type: str
        :param event_type: Filter on the livestream status of the videos.
        :type event_type: str
        :param for_content_owner: Search owned by a content owner.
        :type for_content_owner: bool
        :param for_developer: Restrict the search to only retrieve videos uploaded using the project id of the authenticated user.
        :type for_developer: bool
        :param for_mine: Search for the private videos of the authenticated user.
        :type for_mine: bool
        :param location: Filter on location of the video
        :type location: str
        :param location_radius: Filter on distance from the location (specified above).
        :type location_radius: str
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.
        :type max_results: int
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param order: Sort order of the results.
        :type order: str
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.
        :type page_token: str
        :param published_after: Filter on resources published after this date.
        :type published_after: str
        :param published_before: Filter on resources published before this date.
        :type published_before: str
        :param q: Textual search terms to match.
        :type q: str
        :param region_code: Display the content as seen by viewers in this country.
        :type region_code: str
        :param relevance_language: Return results relevant to this language.
        :type relevance_language: str
        :param safe_search: Indicates whether the search results should include restricted content as well as standard content.
        :type safe_search: str
        :param topic_id: Restrict results to a particular topic.
        :type topic_id: str
        :param type: Restrict results to a particular set of resource types from One Platform.
        :type type: List[str]
        :param video_caption: Filter on the presence of captions on the videos.
        :type video_caption: str
        :param video_category_id: Filter on videos in a specific category.
        :type video_category_id: str
        :param video_definition: Filter on the definition of the videos.
        :type video_definition: str
        :param video_dimension: Filter on 3d videos.
        :type video_dimension: str
        :param video_duration: Filter on the duration of the videos.
        :type video_duration: str
        :param video_embeddable: Filter on embeddable videos.
        :type video_embeddable: str
        :param video_license: Filter on the license of the videos.
        :type video_license: str
        :param video_paid_product_placement:
        :type video_paid_product_placement: str
        :param video_syndicated: Filter on syndicated videos.
        :type video_syndicated: str
        :param video_type: Filter on videos of a specific type.
        :type video_type: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_search_list_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            channel_id=channel_id,
            channel_type=channel_type,
            event_type=event_type,
            for_content_owner=for_content_owner,
            for_developer=for_developer,
            for_mine=for_mine,
            location=location,
            location_radius=location_radius,
            max_results=max_results,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            order=order,
            page_token=page_token,
            published_after=published_after,
            published_before=published_before,
            q=q,
            region_code=region_code,
            relevance_language=relevance_language,
            safe_search=safe_search,
            topic_id=topic_id,
            type=type,
            video_caption=video_caption,
            video_category_id=video_category_id,
            video_definition=video_definition,
            video_dimension=video_dimension,
            video_duration=video_duration,
            video_embeddable=video_embeddable,
            video_license=video_license,
            video_paid_product_placement=video_paid_product_placement,
            video_syndicated=video_syndicated,
            video_type=video_type,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SearchListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_search_list_with_http_info(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies a comma-separated list of one or more search resource properties that the API response will include. Set the parameter value to snippet.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        channel_id: Annotated[Optional[StrictStr], Field(description="Filter on resources belonging to this channelId.")] = None,
        channel_type: Annotated[Optional[StrictStr], Field(description="Add a filter on the channel search.")] = None,
        event_type: Annotated[Optional[StrictStr], Field(description="Filter on the livestream status of the videos.")] = None,
        for_content_owner: Annotated[Optional[StrictBool], Field(description="Search owned by a content owner.")] = None,
        for_developer: Annotated[Optional[StrictBool], Field(description="Restrict the search to only retrieve videos uploaded using the project id of the authenticated user.")] = None,
        for_mine: Annotated[Optional[StrictBool], Field(description="Search for the private videos of the authenticated user.")] = None,
        location: Annotated[Optional[StrictStr], Field(description="Filter on location of the video")] = None,
        location_radius: Annotated[Optional[StrictStr], Field(description="Filter on distance from the location (specified above).")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=0)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        order: Annotated[Optional[StrictStr], Field(description="Sort order of the results.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.")] = None,
        published_after: Annotated[Optional[StrictStr], Field(description="Filter on resources published after this date.")] = None,
        published_before: Annotated[Optional[StrictStr], Field(description="Filter on resources published before this date.")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Textual search terms to match.")] = None,
        region_code: Annotated[Optional[StrictStr], Field(description="Display the content as seen by viewers in this country.")] = None,
        relevance_language: Annotated[Optional[StrictStr], Field(description="Return results relevant to this language.")] = None,
        safe_search: Annotated[Optional[StrictStr], Field(description="Indicates whether the search results should include restricted content as well as standard content.")] = None,
        topic_id: Annotated[Optional[StrictStr], Field(description="Restrict results to a particular topic.")] = None,
        type: Annotated[Optional[List[StrictStr]], Field(description="Restrict results to a particular set of resource types from One Platform.")] = None,
        video_caption: Annotated[Optional[StrictStr], Field(description="Filter on the presence of captions on the videos.")] = None,
        video_category_id: Annotated[Optional[StrictStr], Field(description="Filter on videos in a specific category.")] = None,
        video_definition: Annotated[Optional[StrictStr], Field(description="Filter on the definition of the videos.")] = None,
        video_dimension: Annotated[Optional[StrictStr], Field(description="Filter on 3d videos.")] = None,
        video_duration: Annotated[Optional[StrictStr], Field(description="Filter on the duration of the videos.")] = None,
        video_embeddable: Annotated[Optional[StrictStr], Field(description="Filter on embeddable videos.")] = None,
        video_license: Annotated[Optional[StrictStr], Field(description="Filter on the license of the videos.")] = None,
        video_paid_product_placement: Optional[StrictStr] = None,
        video_syndicated: Annotated[Optional[StrictStr], Field(description="Filter on syndicated videos.")] = None,
        video_type: Annotated[Optional[StrictStr], Field(description="Filter on videos of a specific type.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[SearchListResponse]:
        """youtube_search_list

        Retrieves a list of search resources

        :param part: The *part* parameter specifies a comma-separated list of one or more search resource properties that the API response will include. Set the parameter value to snippet. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param channel_id: Filter on resources belonging to this channelId.
        :type channel_id: str
        :param channel_type: Add a filter on the channel search.
        :type channel_type: str
        :param event_type: Filter on the livestream status of the videos.
        :type event_type: str
        :param for_content_owner: Search owned by a content owner.
        :type for_content_owner: bool
        :param for_developer: Restrict the search to only retrieve videos uploaded using the project id of the authenticated user.
        :type for_developer: bool
        :param for_mine: Search for the private videos of the authenticated user.
        :type for_mine: bool
        :param location: Filter on location of the video
        :type location: str
        :param location_radius: Filter on distance from the location (specified above).
        :type location_radius: str
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.
        :type max_results: int
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param order: Sort order of the results.
        :type order: str
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.
        :type page_token: str
        :param published_after: Filter on resources published after this date.
        :type published_after: str
        :param published_before: Filter on resources published before this date.
        :type published_before: str
        :param q: Textual search terms to match.
        :type q: str
        :param region_code: Display the content as seen by viewers in this country.
        :type region_code: str
        :param relevance_language: Return results relevant to this language.
        :type relevance_language: str
        :param safe_search: Indicates whether the search results should include restricted content as well as standard content.
        :type safe_search: str
        :param topic_id: Restrict results to a particular topic.
        :type topic_id: str
        :param type: Restrict results to a particular set of resource types from One Platform.
        :type type: List[str]
        :param video_caption: Filter on the presence of captions on the videos.
        :type video_caption: str
        :param video_category_id: Filter on videos in a specific category.
        :type video_category_id: str
        :param video_definition: Filter on the definition of the videos.
        :type video_definition: str
        :param video_dimension: Filter on 3d videos.
        :type video_dimension: str
        :param video_duration: Filter on the duration of the videos.
        :type video_duration: str
        :param video_embeddable: Filter on embeddable videos.
        :type video_embeddable: str
        :param video_license: Filter on the license of the videos.
        :type video_license: str
        :param video_paid_product_placement:
        :type video_paid_product_placement: str
        :param video_syndicated: Filter on syndicated videos.
        :type video_syndicated: str
        :param video_type: Filter on videos of a specific type.
        :type video_type: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_search_list_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            channel_id=channel_id,
            channel_type=channel_type,
            event_type=event_type,
            for_content_owner=for_content_owner,
            for_developer=for_developer,
            for_mine=for_mine,
            location=location,
            location_radius=location_radius,
            max_results=max_results,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            order=order,
            page_token=page_token,
            published_after=published_after,
            published_before=published_before,
            q=q,
            region_code=region_code,
            relevance_language=relevance_language,
            safe_search=safe_search,
            topic_id=topic_id,
            type=type,
            video_caption=video_caption,
            video_category_id=video_category_id,
            video_definition=video_definition,
            video_dimension=video_dimension,
            video_duration=video_duration,
            video_embeddable=video_embeddable,
            video_license=video_license,
            video_paid_product_placement=video_paid_product_placement,
            video_syndicated=video_syndicated,
            video_type=video_type,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SearchListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_search_list_without_preload_content(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies a comma-separated list of one or more search resource properties that the API response will include. Set the parameter value to snippet.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        channel_id: Annotated[Optional[StrictStr], Field(description="Filter on resources belonging to this channelId.")] = None,
        channel_type: Annotated[Optional[StrictStr], Field(description="Add a filter on the channel search.")] = None,
        event_type: Annotated[Optional[StrictStr], Field(description="Filter on the livestream status of the videos.")] = None,
        for_content_owner: Annotated[Optional[StrictBool], Field(description="Search owned by a content owner.")] = None,
        for_developer: Annotated[Optional[StrictBool], Field(description="Restrict the search to only retrieve videos uploaded using the project id of the authenticated user.")] = None,
        for_mine: Annotated[Optional[StrictBool], Field(description="Search for the private videos of the authenticated user.")] = None,
        location: Annotated[Optional[StrictStr], Field(description="Filter on location of the video")] = None,
        location_radius: Annotated[Optional[StrictStr], Field(description="Filter on distance from the location (specified above).")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=50, strict=True, ge=0)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.")] = None,
        on_behalf_of_content_owner: Annotated[Optional[StrictStr], Field(description="*Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.")] = None,
        order: Annotated[Optional[StrictStr], Field(description="Sort order of the results.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.")] = None,
        published_after: Annotated[Optional[StrictStr], Field(description="Filter on resources published after this date.")] = None,
        published_before: Annotated[Optional[StrictStr], Field(description="Filter on resources published before this date.")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Textual search terms to match.")] = None,
        region_code: Annotated[Optional[StrictStr], Field(description="Display the content as seen by viewers in this country.")] = None,
        relevance_language: Annotated[Optional[StrictStr], Field(description="Return results relevant to this language.")] = None,
        safe_search: Annotated[Optional[StrictStr], Field(description="Indicates whether the search results should include restricted content as well as standard content.")] = None,
        topic_id: Annotated[Optional[StrictStr], Field(description="Restrict results to a particular topic.")] = None,
        type: Annotated[Optional[List[StrictStr]], Field(description="Restrict results to a particular set of resource types from One Platform.")] = None,
        video_caption: Annotated[Optional[StrictStr], Field(description="Filter on the presence of captions on the videos.")] = None,
        video_category_id: Annotated[Optional[StrictStr], Field(description="Filter on videos in a specific category.")] = None,
        video_definition: Annotated[Optional[StrictStr], Field(description="Filter on the definition of the videos.")] = None,
        video_dimension: Annotated[Optional[StrictStr], Field(description="Filter on 3d videos.")] = None,
        video_duration: Annotated[Optional[StrictStr], Field(description="Filter on the duration of the videos.")] = None,
        video_embeddable: Annotated[Optional[StrictStr], Field(description="Filter on embeddable videos.")] = None,
        video_license: Annotated[Optional[StrictStr], Field(description="Filter on the license of the videos.")] = None,
        video_paid_product_placement: Optional[StrictStr] = None,
        video_syndicated: Annotated[Optional[StrictStr], Field(description="Filter on syndicated videos.")] = None,
        video_type: Annotated[Optional[StrictStr], Field(description="Filter on videos of a specific type.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_search_list

        Retrieves a list of search resources

        :param part: The *part* parameter specifies a comma-separated list of one or more search resource properties that the API response will include. Set the parameter value to snippet. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param channel_id: Filter on resources belonging to this channelId.
        :type channel_id: str
        :param channel_type: Add a filter on the channel search.
        :type channel_type: str
        :param event_type: Filter on the livestream status of the videos.
        :type event_type: str
        :param for_content_owner: Search owned by a content owner.
        :type for_content_owner: bool
        :param for_developer: Restrict the search to only retrieve videos uploaded using the project id of the authenticated user.
        :type for_developer: bool
        :param for_mine: Search for the private videos of the authenticated user.
        :type for_mine: bool
        :param location: Filter on location of the video
        :type location: str
        :param location_radius: Filter on distance from the location (specified above).
        :type location_radius: str
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set.
        :type max_results: int
        :param on_behalf_of_content_owner: *Note:* This parameter is intended exclusively for YouTube content partners. The *onBehalfOfContentOwner* parameter indicates that the request's authorization credentials identify a YouTube CMS user who is acting on behalf of the content owner specified in the parameter value. This parameter is intended for YouTube content partners that own and manage many different YouTube channels. It allows content owners to authenticate once and get access to all their video and channel data, without having to provide authentication credentials for each individual channel. The CMS account that the user authenticates with must be linked to the specified YouTube content owner.
        :type on_behalf_of_content_owner: str
        :param order: Sort order of the results.
        :type order: str
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken and prevPageToken properties identify other pages that could be retrieved.
        :type page_token: str
        :param published_after: Filter on resources published after this date.
        :type published_after: str
        :param published_before: Filter on resources published before this date.
        :type published_before: str
        :param q: Textual search terms to match.
        :type q: str
        :param region_code: Display the content as seen by viewers in this country.
        :type region_code: str
        :param relevance_language: Return results relevant to this language.
        :type relevance_language: str
        :param safe_search: Indicates whether the search results should include restricted content as well as standard content.
        :type safe_search: str
        :param topic_id: Restrict results to a particular topic.
        :type topic_id: str
        :param type: Restrict results to a particular set of resource types from One Platform.
        :type type: List[str]
        :param video_caption: Filter on the presence of captions on the videos.
        :type video_caption: str
        :param video_category_id: Filter on videos in a specific category.
        :type video_category_id: str
        :param video_definition: Filter on the definition of the videos.
        :type video_definition: str
        :param video_dimension: Filter on 3d videos.
        :type video_dimension: str
        :param video_duration: Filter on the duration of the videos.
        :type video_duration: str
        :param video_embeddable: Filter on embeddable videos.
        :type video_embeddable: str
        :param video_license: Filter on the license of the videos.
        :type video_license: str
        :param video_paid_product_placement:
        :type video_paid_product_placement: str
        :param video_syndicated: Filter on syndicated videos.
        :type video_syndicated: str
        :param video_type: Filter on videos of a specific type.
        :type video_type: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_search_list_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            channel_id=channel_id,
            channel_type=channel_type,
            event_type=event_type,
            for_content_owner=for_content_owner,
            for_developer=for_developer,
            for_mine=for_mine,
            location=location,
            location_radius=location_radius,
            max_results=max_results,
            on_behalf_of_content_owner=on_behalf_of_content_owner,
            order=order,
            page_token=page_token,
            published_after=published_after,
            published_before=published_before,
            q=q,
            region_code=region_code,
            relevance_language=relevance_language,
            safe_search=safe_search,
            topic_id=topic_id,
            type=type,
            video_caption=video_caption,
            video_category_id=video_category_id,
            video_definition=video_definition,
            video_dimension=video_dimension,
            video_duration=video_duration,
            video_embeddable=video_embeddable,
            video_license=video_license,
            video_paid_product_placement=video_paid_product_placement,
            video_syndicated=video_syndicated,
            video_type=video_type,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SearchListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_search_list_serialize(
        self,
        part,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        channel_id,
        channel_type,
        event_type,
        for_content_owner,
        for_developer,
        for_mine,
        location,
        location_radius,
        max_results,
        on_behalf_of_content_owner,
        order,
        page_token,
        published_after,
        published_before,
        q,
        region_code,
        relevance_language,
        safe_search,
        topic_id,
        type,
        video_caption,
        video_category_id,
        video_definition,
        video_dimension,
        video_duration,
        video_embeddable,
        video_license,
        video_paid_product_placement,
        video_syndicated,
        video_type,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
            'part': 'multi',
            'type': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if part is not None:
            
            _query_params.append(('part', part))
            
        if channel_id is not None:
            
            _query_params.append(('channelId', channel_id))
            
        if channel_type is not None:
            
            _query_params.append(('channelType', channel_type))
            
        if event_type is not None:
            
            _query_params.append(('eventType', event_type))
            
        if for_content_owner is not None:
            
            _query_params.append(('forContentOwner', for_content_owner))
            
        if for_developer is not None:
            
            _query_params.append(('forDeveloper', for_developer))
            
        if for_mine is not None:
            
            _query_params.append(('forMine', for_mine))
            
        if location is not None:
            
            _query_params.append(('location', location))
            
        if location_radius is not None:
            
            _query_params.append(('locationRadius', location_radius))
            
        if max_results is not None:
            
            _query_params.append(('maxResults', max_results))
            
        if on_behalf_of_content_owner is not None:
            
            _query_params.append(('onBehalfOfContentOwner', on_behalf_of_content_owner))
            
        if order is not None:
            
            _query_params.append(('order', order))
            
        if page_token is not None:
            
            _query_params.append(('pageToken', page_token))
            
        if published_after is not None:
            
            _query_params.append(('publishedAfter', published_after))
            
        if published_before is not None:
            
            _query_params.append(('publishedBefore', published_before))
            
        if q is not None:
            
            _query_params.append(('q', q))
            
        if region_code is not None:
            
            _query_params.append(('regionCode', region_code))
            
        if relevance_language is not None:
            
            _query_params.append(('relevanceLanguage', relevance_language))
            
        if safe_search is not None:
            
            _query_params.append(('safeSearch', safe_search))
            
        if topic_id is not None:
            
            _query_params.append(('topicId', topic_id))
            
        if type is not None:
            
            _query_params.append(('type', type))
            
        if video_caption is not None:
            
            _query_params.append(('videoCaption', video_caption))
            
        if video_category_id is not None:
            
            _query_params.append(('videoCategoryId', video_category_id))
            
        if video_definition is not None:
            
            _query_params.append(('videoDefinition', video_definition))
            
        if video_dimension is not None:
            
            _query_params.append(('videoDimension', video_dimension))
            
        if video_duration is not None:
            
            _query_params.append(('videoDuration', video_duration))
            
        if video_embeddable is not None:
            
            _query_params.append(('videoEmbeddable', video_embeddable))
            
        if video_license is not None:
            
            _query_params.append(('videoLicense', video_license))
            
        if video_paid_product_placement is not None:
            
            _query_params.append(('videoPaidProductPlacement', video_paid_product_placement))
            
        if video_syndicated is not None:
            
            _query_params.append(('videoSyndicated', video_syndicated))
            
        if video_type is not None:
            
            _query_params.append(('videoType', video_type))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/youtube/v3/search',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.video_file_details import VideoFileDetails

class TestVideoFileDetails(unittest.TestCase):
    """VideoFileDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VideoFileDetails:
        """Test VideoFileDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VideoFileDetails`
        """
        model = VideoFileDetails()
        if include_optional:
            return VideoFileDetails(
                audio_streams = [
                    youtube_ti.models.video_file_details_audio_stream.VideoFileDetailsAudioStream(
                        bitrate_bps = '', 
                        channel_count = 56, 
                        codec = '', 
                        vendor = '', )
                    ],
                bitrate_bps = '',
                container = '',
                creation_time = '',
                duration_ms = '',
                file_name = '',
                file_size = '',
                file_type = 'video',
                video_streams = [
                    youtube_ti.models.video_file_details_video_stream.VideoFileDetailsVideoStream(
                        aspect_ratio = 1.337, 
                        bitrate_bps = '', 
                        codec = '', 
                        frame_rate_fps = 1.337, 
                        height_pixels = 56, 
                        rotation = 'none', 
                        vendor = '', 
                        width_pixels = 56, )
                    ]
            )
        else:
            return VideoFileDetails(
        )
        """

    def testVideoFileDetails(self):
        """Test VideoFileDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from youtube_ti.models.page_info import PageInfo
from youtube_ti.models.video_category import VideoCategory
from typing import Optional, Set
from typing_extensions import Self

class VideoCategoryListResponse(BaseModel):
    """
    VideoCategoryListResponse
    """ # noqa: E501
    etag: Optional[StrictStr] = Field(default=None, description="Etag of this resource.")
    event_id: Optional[StrictStr] = Field(default=None, description="Serialized EventId of the request which produced this response.", alias="eventId")
    items: Optional[List[VideoCategory]] = Field(default=None, description="A list of video categories that can be associated with YouTube videos. In this map, the video category ID is the map key, and its value is the corresponding videoCategory resource.")
    kind: Optional[StrictStr] = Field(default='youtube#videoCategoryListResponse', description="Identifies what kind of resource this is. Value: the fixed string \"youtube#videoCategoryListResponse\".")
    next_page_token: Optional[StrictStr] = Field(default=None, description="The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.", alias="nextPageToken")
    page_info: Optional[PageInfo] = Field(default=None, alias="pageInfo")
    prev_page_token: Optional[StrictStr] = Field(default=None, description="The token that can be used as the value of the pageToken parameter to retrieve the previous page in the result set.", alias="prevPageToken")
    token_pagination: Optional[Dict[str, Any]] = Field(default=None, description="Stub token pagination template to suppress results.", alias="tokenPagination")
    visitor_id: Optional[StrictStr] = Field(default=None, description="The visitorId identifies the visitor.", alias="visitorId")
    __properties: ClassVar[List[str]] = ["etag", "eventId", "items", "kind", "nextPageToken", "pageInfo", "prevPageToken", "tokenPagination", "visitorId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VideoCategoryListResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict['items'] = _items
        # override the default output from pydantic by calling `to_dict()` of page_info
        if self.page_info:
            _dict['pageInfo'] = self.page_info.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VideoCategoryListResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "etag": obj.get("etag"),
            "eventId": obj.get("eventId"),
            "items": [VideoCategory.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "kind": obj.get("kind") if obj.get("kind") is not None else 'youtube#videoCategoryListResponse',
            "nextPageToken": obj.get("nextPageToken"),
            "pageInfo": PageInfo.from_dict(obj["pageInfo"]) if obj.get("pageInfo") is not None else None,
            "prevPageToken": obj.get("prevPageToken"),
            "tokenPagination": obj.get("tokenPagination"),
            "visitorId": obj.get("visitorId")
        })
        return _obj





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool, StrictStr, field_validator
from typing import List, Optional
from typing_extensions import Annotated
from youtube_ti.models.live_chat_message import LiveChatMessage
from youtube_ti.models.live_chat_message_list_response import LiveChatMessageListResponse

from youtube_ti.api_client import ApiClient, RequestSerialized
from youtube_ti.api_response import ApiResponse
from youtube_ti.rest import RESTResponseType


class LiveChatMessagesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def youtube_live_chat_messages_delete(
        self,
        id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> None:
        """youtube_live_chat_messages_delete

        Deletes a chat message.

        :param id: (required)
        :type id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_delete_serialize(
            id=id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_live_chat_messages_delete_with_http_info(
        self,
        id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[None]:
        """youtube_live_chat_messages_delete

        Deletes a chat message.

        :param id: (required)
        :type id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_delete_serialize(
            id=id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_live_chat_messages_delete_without_preload_content(
        self,
        id: StrictStr,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_live_chat_messages_delete

        Deletes a chat message.

        :param id: (required)
        :type id: str
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_delete_serialize(
            id=id,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_live_chat_messages_delete_serialize(
        self,
        id,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if id is not None:
            
            _query_params.append(('id', id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/youtube/v3/liveChat/messages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def youtube_live_chat_messages_insert(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter serves two purposes. It identifies the properties that the write operation will set as well as the properties that the API response will include. Set the parameter value to snippet.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        live_chat_message: Optional[LiveChatMessage] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> LiveChatMessage:
        """youtube_live_chat_messages_insert

        Inserts a new resource into this collection.

        :param part: The *part* parameter serves two purposes. It identifies the properties that the write operation will set as well as the properties that the API response will include. Set the parameter value to snippet. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param live_chat_message:
        :type live_chat_message: LiveChatMessage
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_insert_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            live_chat_message=live_chat_message,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessage",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_live_chat_messages_insert_with_http_info(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter serves two purposes. It identifies the properties that the write operation will set as well as the properties that the API response will include. Set the parameter value to snippet.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        live_chat_message: Optional[LiveChatMessage] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[LiveChatMessage]:
        """youtube_live_chat_messages_insert

        Inserts a new resource into this collection.

        :param part: The *part* parameter serves two purposes. It identifies the properties that the write operation will set as well as the properties that the API response will include. Set the parameter value to snippet. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param live_chat_message:
        :type live_chat_message: LiveChatMessage
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_insert_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            live_chat_message=live_chat_message,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessage",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_live_chat_messages_insert_without_preload_content(
        self,
        part: Annotated[List[StrictStr], Field(description="The *part* parameter serves two purposes. It identifies the properties that the write operation will set as well as the properties that the API response will include. Set the parameter value to snippet.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        live_chat_message: Optional[LiveChatMessage] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_live_chat_messages_insert

        Inserts a new resource into this collection.

        :param part: The *part* parameter serves two purposes. It identifies the properties that the write operation will set as well as the properties that the API response will include. Set the parameter value to snippet. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param live_chat_message:
        :type live_chat_message: LiveChatMessage
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_insert_serialize(
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            live_chat_message=live_chat_message,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessage",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_live_chat_messages_insert_serialize(
        self,
        part,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        live_chat_message,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
            'part': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if part is not None:
            
            _query_params.append(('part', part))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if live_chat_message is not None:
            _body_params = live_chat_message


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )

        # set the HTTP header `Content-Type`
        if content_type__:
            _header_params['Content-Type'] = content_type__
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/youtube/v3/liveChat/messages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def youtube_live_chat_messages_list(
        self,
        live_chat_id: Annotated[StrictStr, Field(description="The id of the live chat for which comments should be returned.")],
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies the liveChatComment resource parts that the API response will include. Supported values are id, snippet, and authorDetails.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        hl: Annotated[Optional[StrictStr], Field(description="Specifies the localization language in which the system messages should be returned.")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=2000, strict=True, ge=200)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set. Not used in the streaming RPC.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken property identify other pages that could be retrieved.")] = None,
        profile_image_size: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=16)]], Field(description="Specifies the size of the profile image that should be returned for each user.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> LiveChatMessageListResponse:
        """youtube_live_chat_messages_list

        Retrieves a list of resources, possibly filtered.

        :param live_chat_id: The id of the live chat for which comments should be returned. (required)
        :type live_chat_id: str
        :param part: The *part* parameter specifies the liveChatComment resource parts that the API response will include. Supported values are id, snippet, and authorDetails. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param hl: Specifies the localization language in which the system messages should be returned.
        :type hl: str
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set. Not used in the streaming RPC.
        :type max_results: int
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken property identify other pages that could be retrieved.
        :type page_token: str
        :param profile_image_size: Specifies the size of the profile image that should be returned for each user.
        :type profile_image_size: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_list_serialize(
            live_chat_id=live_chat_id,
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            hl=hl,
            max_results=max_results,
            page_token=page_token,
            profile_image_size=profile_image_size,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessageListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_live_chat_messages_list_with_http_info(
        self,
        live_chat_id: Annotated[StrictStr, Field(description="The id of the live chat for which comments should be returned.")],
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies the liveChatComment resource parts that the API response will include. Supported values are id, snippet, and authorDetails.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        hl: Annotated[Optional[StrictStr], Field(description="Specifies the localization language in which the system messages should be returned.")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=2000, strict=True, ge=200)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set. Not used in the streaming RPC.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken property identify other pages that could be retrieved.")] = None,
        profile_image_size: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=16)]], Field(description="Specifies the size of the profile image that should be returned for each user.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[LiveChatMessageListResponse]:
        """youtube_live_chat_messages_list

        Retrieves a list of resources, possibly filtered.

        :param live_chat_id: The id of the live chat for which comments should be returned. (required)
        :type live_chat_id: str
        :param part: The *part* parameter specifies the liveChatComment resource parts that the API response will include. Supported values are id, snippet, and authorDetails. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param hl: Specifies the localization language in which the system messages should be returned.
        :type hl: str
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set. Not used in the streaming RPC.
        :type max_results: int
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken property identify other pages that could be retrieved.
        :type page_token: str
        :param profile_image_size: Specifies the size of the profile image that should be returned for each user.
        :type profile_image_size: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_list_serialize(
            live_chat_id=live_chat_id,
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            hl=hl,
            max_results=max_results,
            page_token=page_token,
            profile_image_size=profile_image_size,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessageListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_live_chat_messages_list_without_preload_content(
        self,
        live_chat_id: Annotated[StrictStr, Field(description="The id of the live chat for which comments should be returned.")],
        part: Annotated[List[StrictStr], Field(description="The *part* parameter specifies the liveChatComment resource parts that the API response will include. Supported values are id, snippet, and authorDetails.")],
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        hl: Annotated[Optional[StrictStr], Field(description="Specifies the localization language in which the system messages should be returned.")] = None,
        max_results: Annotated[Optional[Annotated[int, Field(le=2000, strict=True, ge=200)]], Field(description="The *maxResults* parameter specifies the maximum number of items that should be returned in the result set. Not used in the streaming RPC.")] = None,
        page_token: Annotated[Optional[StrictStr], Field(description="The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken property identify other pages that could be retrieved.")] = None,
        profile_image_size: Annotated[Optional[Annotated[int, Field(le=720, strict=True, ge=16)]], Field(description="Specifies the size of the profile image that should be returned for each user.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_live_chat_messages_list

        Retrieves a list of resources, possibly filtered.

        :param live_chat_id: The id of the live chat for which comments should be returned. (required)
        :type live_chat_id: str
        :param part: The *part* parameter specifies the liveChatComment resource parts that the API response will include. Supported values are id, snippet, and authorDetails. (required)
        :type part: List[str]
        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param hl: Specifies the localization language in which the system messages should be returned.
        :type hl: str
        :param max_results: The *maxResults* parameter specifies the maximum number of items that should be returned in the result set. Not used in the streaming RPC.
        :type max_results: int
        :param page_token: The *pageToken* parameter identifies a specific page in the result set that should be returned. In an API response, the nextPageToken property identify other pages that could be retrieved.
        :type page_token: str
        :param profile_image_size: Specifies the size of the profile image that should be returned for each user.
        :type profile_image_size: int
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_list_serialize(
            live_chat_id=live_chat_id,
            part=part,
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            hl=hl,
            max_results=max_results,
            page_token=page_token,
            profile_image_size=profile_image_size,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessageListResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_live_chat_messages_list_serialize(
        self,
        live_chat_id,
        part,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        hl,
        max_results,
        page_token,
        profile_image_size,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
            'part': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if live_chat_id is not None:
            
            _query_params.append(('liveChatId', live_chat_id))
            
        if part is not None:
            
            _query_params.append(('part', part))
            
        if hl is not None:
            
            _query_params.append(('hl', hl))
            
        if max_results is not None:
            
            _query_params.append(('maxResults', max_results))
            
        if page_token is not None:
            
            _query_params.append(('pageToken', page_token))
            
        if profile_image_size is not None:
            
            _query_params.append(('profileImageSize', profile_image_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/youtube/v3/liveChat/messages',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )




    @validate_call
    def youtube_live_chat_messages_transition(
        self,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        id: Annotated[Optional[StrictStr], Field(description="The ID that uniquely identify the chat message event to transition.")] = None,
        status: Annotated[Optional[StrictStr], Field(description="The status to which the chat event is going to transition.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> LiveChatMessage:
        """youtube_live_chat_messages_transition

        Transition a durable chat event.

        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param id: The ID that uniquely identify the chat message event to transition.
        :type id: str
        :param status: The status to which the chat event is going to transition.
        :type status: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_transition_serialize(
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            id=id,
            status=status,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessage",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def youtube_live_chat_messages_transition_with_http_info(
        self,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        id: Annotated[Optional[StrictStr], Field(description="The ID that uniquely identify the chat message event to transition.")] = None,
        status: Annotated[Optional[StrictStr], Field(description="The status to which the chat event is going to transition.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> ApiResponse[LiveChatMessage]:
        """youtube_live_chat_messages_transition

        Transition a durable chat event.

        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param id: The ID that uniquely identify the chat message event to transition.
        :type id: str
        :param status: The status to which the chat event is going to transition.
        :type status: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_transition_serialize(
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            id=id,
            status=status,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessage",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def youtube_live_chat_messages_transition_without_preload_content(
        self,
        oauth_token: Annotated[Optional[StrictStr], Field(description="OAuth 2.0 token for the current user.")] = None,
        key: Annotated[Optional[StrictStr], Field(description="API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.")] = None,
        upload_type: Annotated[Optional[StrictStr], Field(description="Legacy upload protocol for media (e.g. \"media\", \"multipart\").")] = None,
        quota_user: Annotated[Optional[StrictStr], Field(description="Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.")] = None,
        upload_protocol: Annotated[Optional[StrictStr], Field(description="Upload protocol for media (e.g. \"raw\", \"multipart\").")] = None,
        param_callback: Annotated[Optional[StrictStr], Field(description="JSONP")] = None,
        fields: Annotated[Optional[StrictStr], Field(description="Selector specifying which fields to include in a partial response.")] = None,
        xgafv: Annotated[Optional[StrictStr], Field(description="V1 error format.")] = None,
        pretty_print: Annotated[Optional[StrictBool], Field(description="Returns response with indentations and line breaks.")] = None,
        access_token: Annotated[Optional[StrictStr], Field(description="OAuth access token.")] = None,
        alt: Annotated[Optional[StrictStr], Field(description="Data format for response.")] = None,
        id: Annotated[Optional[StrictStr], Field(description="The ID that uniquely identify the chat message event to transition.")] = None,
        status: Annotated[Optional[StrictStr], Field(description="The status to which the chat event is going to transition.")] = None,
        request_timeout__: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        request_auth__: Optional[Dict[StrictStr, Any]] = None,
        content_type__: Optional[StrictStr] = None,
        headers__: Optional[Dict[StrictStr, Any]] = None,
        host__: Optional[StrictStr] = None,
    ) -> RESTResponseType:
        """youtube_live_chat_messages_transition

        Transition a durable chat event.

        :param oauth_token: OAuth 2.0 token for the current user.
        :type oauth_token: str
        :param key: API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
        :type key: str
        :param upload_type: Legacy upload protocol for media (e.g. \"media\", \"multipart\").
        :type upload_type: str
        :param quota_user: Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
        :type quota_user: str
        :param upload_protocol: Upload protocol for media (e.g. \"raw\", \"multipart\").
        :type upload_protocol: str
        :param param_callback: JSONP
        :type param_callback: str
        :param fields: Selector specifying which fields to include in a partial response.
        :type fields: str
        :param xgafv: V1 error format.
        :type xgafv: str
        :param pretty_print: Returns response with indentations and line breaks.
        :type pretty_print: bool
        :param access_token: OAuth access token.
        :type access_token: str
        :param alt: Data format for response.
        :type alt: str
        :param id: The ID that uniquely identify the chat message event to transition.
        :type id: str
        :param status: The status to which the chat event is going to transition.
        :type status: str
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._youtube_live_chat_messages_transition_serialize(
            oauth_token=oauth_token,
            key=key,
            upload_type=upload_type,
            quota_user=quota_user,
            upload_protocol=upload_protocol,
            param_callback=param_callback,
            fields=fields,
            xgafv=xgafv,
            pretty_print=pretty_print,
            access_token=access_token,
            alt=alt,
            id=id,
            status=status,
            request_auth__=request_auth__,
            content_type__=content_type__,
            headers__=headers__,
            host__=host__
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LiveChatMessage",
        }
        response_data = self.api_client.call_api(
            *_param,
            request_timeout__=request_timeout__
        )
        return response_data.response


    def _youtube_live_chat_messages_transition_serialize(
        self,
        oauth_token,
        key,
        upload_type,
        quota_user,
        upload_protocol,
        param_callback,
        fields,
        xgafv,
        pretty_print,
        access_token,
        alt,
        id,
        status,
        request_auth__,
        content_type__,
        headers__,
        host__,
    ) -> RequestSerialized:


        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = headers__ or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if oauth_token is not None:
            
            _query_params.append(('oauth_token', oauth_token))
            
        if key is not None:
            
            _query_params.append(('key', key))
            
        if upload_type is not None:
            
            _query_params.append(('uploadType', upload_type))
            
        if quota_user is not None:
            
            _query_params.append(('quotaUser', quota_user))
            
        if upload_protocol is not None:
            
            _query_params.append(('upload_protocol', upload_protocol))
            
        if param_callback is not None:
            
            _query_params.append(('callback', param_callback))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if xgafv is not None:
            
            _query_params.append(('$.xgafv', xgafv))
            
        if pretty_print is not None:
            
            _query_params.append(('prettyPrint', pretty_print))
            
        if access_token is not None:
            
            _query_params.append(('access_token', access_token))
            
        if alt is not None:
            
            _query_params.append(('alt', alt))
            
        if id is not None:
            
            _query_params.append(('id', id))
            
        if status is not None:
            
            _query_params.append(('status', status))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    '*/*'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Oauth2c', 
            'Oauth2'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/youtube/v3/liveChat/messages/transition',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            host__=host__,
            request_auth__=request_auth__
        )





# coding: utf-8

"""
    YouTube Data API v3

    The YouTube Data API v3 is an API that provides access to YouTube data, such as videos, playlists, and channels.

    The version of the OpenAPI document: v3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from youtube_ti.models.video_list_response import VideoListResponse

class TestVideoListResponse(unittest.TestCase):
    """VideoListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VideoListResponse:
        """Test VideoListResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VideoListResponse`
        """
        model = VideoListResponse()
        if include_optional:
            return VideoListResponse(
                etag = '',
                event_id = '',
                items = [
                    youtube_ti.models.video.Video(
                        age_gating = youtube_ti.models.video_age_gating.VideoAgeGating(
                            alcohol_content = True, 
                            restricted = True, 
                            video_game_rating = 'anyone', ), 
                        content_details = youtube_ti.models.video_content_details.VideoContentDetails(
                            caption = 'true', 
                            content_rating = youtube_ti.models.content_rating.ContentRating(
                                acb_rating = 'acbUnspecified', 
                                agcom_rating = 'agcomUnspecified', 
                                anatel_rating = 'anatelUnspecified', 
                                bbfc_rating = 'bbfcUnspecified', 
                                bfvc_rating = 'bfvcUnspecified', 
                                bmukk_rating = 'bmukkUnspecified', 
                                catv_rating = 'catvUnspecified', 
                                catvfr_rating = 'catvfrUnspecified', 
                                cbfc_rating = 'cbfcUnspecified', 
                                ccc_rating = 'cccUnspecified', 
                                cce_rating = 'cceUnspecified', 
                                chfilm_rating = 'chfilmUnspecified', 
                                chvrs_rating = 'chvrsUnspecified', 
                                cicf_rating = 'cicfUnspecified', 
                                cna_rating = 'cnaUnspecified', 
                                cnc_rating = 'cncUnspecified', 
                                csa_rating = 'csaUnspecified', 
                                cscf_rating = 'cscfUnspecified', 
                                czfilm_rating = 'czfilmUnspecified', 
                                djctq_rating = 'djctqUnspecified', 
                                djctq_rating_reasons = [
                                    'djctqRatingReasonUnspecified'
                                    ], 
                                ecbmct_rating = 'ecbmctUnspecified', 
                                eefilm_rating = 'eefilmUnspecified', 
                                egfilm_rating = 'egfilmUnspecified', 
                                eirin_rating = 'eirinUnspecified', 
                                fcbm_rating = 'fcbmUnspecified', 
                                fco_rating = 'fcoUnspecified', 
                                fmoc_rating = 'fmocUnspecified', 
                                fpb_rating = 'fpbUnspecified', 
                                fpb_rating_reasons = [
                                    'fpbRatingReasonUnspecified'
                                    ], 
                                fsk_rating = 'fskUnspecified', 
                                grfilm_rating = 'grfilmUnspecified', 
                                icaa_rating = 'icaaUnspecified', 
                                ifco_rating = 'ifcoUnspecified', 
                                ilfilm_rating = 'ilfilmUnspecified', 
                                incaa_rating = 'incaaUnspecified', 
                                kfcb_rating = 'kfcbUnspecified', 
                                kijkwijzer_rating = 'kijkwijzerUnspecified', 
                                kmrb_rating = 'kmrbUnspecified', 
                                lsf_rating = 'lsfUnspecified', 
                                mccaa_rating = 'mccaaUnspecified', 
                                mccyp_rating = 'mccypUnspecified', 
                                mcst_rating = 'mcstUnspecified', 
                                mda_rating = 'mdaUnspecified', 
                                medietilsynet_rating = 'medietilsynetUnspecified', 
                                meku_rating = 'mekuUnspecified', 
                                mena_mpaa_rating = 'menaMpaaUnspecified', 
                                mibac_rating = 'mibacUnspecified', 
                                moc_rating = 'mocUnspecified', 
                                moctw_rating = 'moctwUnspecified', 
                                mpaa_rating = 'mpaaUnspecified', 
                                mpaat_rating = 'mpaatUnspecified', 
                                mtrcb_rating = 'mtrcbUnspecified', 
                                nbc_rating = 'nbcUnspecified', 
                                nbcpl_rating = 'nbcplUnspecified', 
                                nfrc_rating = 'nfrcUnspecified', 
                                nfvcb_rating = 'nfvcbUnspecified', 
                                nkclv_rating = 'nkclvUnspecified', 
                                nmc_rating = 'nmcUnspecified', 
                                oflc_rating = 'oflcUnspecified', 
                                pefilm_rating = 'pefilmUnspecified', 
                                rcnof_rating = 'rcnofUnspecified', 
                                resorteviolencia_rating = 'resorteviolenciaUnspecified', 
                                rtc_rating = 'rtcUnspecified', 
                                rte_rating = 'rteUnspecified', 
                                russia_rating = 'russiaUnspecified', 
                                skfilm_rating = 'skfilmUnspecified', 
                                smais_rating = 'smaisUnspecified', 
                                smsa_rating = 'smsaUnspecified', 
                                tvpg_rating = 'tvpgUnspecified', 
                                yt_rating = 'ytUnspecified', ), 
                            country_restriction = youtube_ti.models.access_policy.AccessPolicy(
                                allowed = True, 
                                exception = [
                                    ''
                                    ], ), 
                            definition = 'sd', 
                            dimension = '', 
                            duration = '', 
                            has_custom_thumbnail = True, 
                            licensed_content = True, 
                            projection = 'rectangular', 
                            region_restriction = youtube_ti.models.video_content_details_region_restriction.VideoContentDetailsRegionRestriction(
                                allowed = [
                                    ''
                                    ], 
                                blocked = [
                                    ''
                                    ], ), ), 
                        etag = '', 
                        file_details = youtube_ti.models.video_file_details.VideoFileDetails(
                            audio_streams = [
                                youtube_ti.models.video_file_details_audio_stream.VideoFileDetailsAudioStream(
                                    bitrate_bps = '', 
                                    channel_count = 56, 
                                    codec = '', 
                                    vendor = '', )
                                ], 
                            bitrate_bps = '', 
                            container = '', 
                            creation_time = '', 
                            duration_ms = '', 
                            file_name = '', 
                            file_size = '', 
                            file_type = 'video', 
                            video_streams = [
                                youtube_ti.models.video_file_details_video_stream.VideoFileDetailsVideoStream(
                                    aspect_ratio = 1.337, 
                                    bitrate_bps = '', 
                                    codec = '', 
                                    frame_rate_fps = 1.337, 
                                    height_pixels = 56, 
                                    rotation = 'none', 
                                    vendor = '', 
                                    width_pixels = 56, )
                                ], ), 
                        id = '', 
                        kind = 'youtube#video', 
                        live_streaming_details = youtube_ti.models.video_live_streaming_details.VideoLiveStreamingDetails(
                            active_live_chat_id = '', 
                            actual_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            actual_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            concurrent_viewers = '', 
                            scheduled_end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            scheduled_start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        localizations = youtube_ti.models.localizations.localizations(), 
                        monetization_details = youtube_ti.models.video_monetization_details.VideoMonetizationDetails(
                            access = youtube_ti.models.access_policy.AccessPolicy(), ), 
                        paid_product_placement_details = youtube_ti.models.video_paid_product_placement_details.VideoPaidProductPlacementDetails(
                            has_paid_product_placement = True, ), 
                        player = youtube_ti.models.video_player.VideoPlayer(
                            embed_height = '', 
                            embed_html = '', 
                            embed_width = '', ), 
                        processing_details = youtube_ti.models.video_processing_details.VideoProcessingDetails(
                            editor_suggestions_availability = '', 
                            file_details_availability = '', 
                            processing_failure_reason = 'uploadFailed', 
                            processing_issues_availability = '', 
                            processing_progress = youtube_ti.models.video_processing_details_processing_progress.VideoProcessingDetailsProcessingProgress(
                                parts_processed = '', 
                                parts_total = '', 
                                time_left_ms = '', ), 
                            processing_status = 'processing', 
                            tag_suggestions_availability = '', 
                            thumbnails_availability = '', ), 
                        project_details = youtube_ti.models.project_details.projectDetails(), 
                        recording_details = youtube_ti.models.video_recording_details.VideoRecordingDetails(
                            location = youtube_ti.models.geo_point.GeoPoint(
                                altitude = 1.337, 
                                latitude = 1.337, 
                                longitude = 1.337, ), 
                            location_description = '', 
                            recording_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        snippet = youtube_ti.models.video_snippet.VideoSnippet(
                            tags = [
                                ''
                                ], 
                            category_id = '', 
                            channel_id = '', 
                            channel_title = '', 
                            default_audio_language = '', 
                            default_language = '', 
                            description = '', 
                            live_broadcast_content = 'none', 
                            localized = youtube_ti.models.video_localization.VideoLocalization(
                                description = '', 
                                title = '', ), 
                            published_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            thumbnails = youtube_ti.models.thumbnail_details.ThumbnailDetails(
                                default = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                high = youtube_ti.models.thumbnail.Thumbnail(
                                    height = 56, 
                                    url = '', 
                                    width = 56, ), 
                                maxres = , 
                                medium = , 
                                standard = , ), 
                            title = '', ), 
                        statistics = youtube_ti.models.video_statistics.VideoStatistics(
                            comment_count = '', 
                            dislike_count = '', 
                            favorite_count = '', 
                            like_count = '', 
                            view_count = '', ), 
                        status = youtube_ti.models.video_status.VideoStatus(
                            contains_synthetic_media = True, 
                            embeddable = True, 
                            failure_reason = 'conversion', 
                            license = 'youtube', 
                            made_for_kids = True, 
                            privacy_status = 'public', 
                            public_stats_viewable = True, 
                            publish_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            rejection_reason = 'copyright', 
                            self_declared_made_for_kids = True, 
                            upload_status = 'uploaded', ), 
                        suggestions = youtube_ti.models.video_suggestions.VideoSuggestions(
                            editor_suggestions = [
                                'videoAutoLevels'
                                ], 
                            processing_errors = [
                                'audioFile'
                                ], 
                            processing_hints = [
                                'nonStreamableMov'
                                ], 
                            processing_warnings = [
                                'unknownContainer'
                                ], 
                            tag_suggestions = [
                                youtube_ti.models.video_suggestions_tag_suggestion.VideoSuggestionsTagSuggestion(
                                    category_restricts = [
                                        ''
                                        ], 
                                    tag = '', )
                                ], ), 
                        topic_details = youtube_ti.models.video_topic_details.VideoTopicDetails(
                            relevant_topic_ids = [
                                ''
                                ], 
                            topic_categories = [
                                ''
                                ], 
                            topic_ids = [
                                ''
                                ], ), )
                    ],
                kind = 'youtube#videoListResponse',
                next_page_token = '',
                page_info = youtube_ti.models.page_info.PageInfo(
                    results_per_page = 56, 
                    total_results = 56, ),
                prev_page_token = '',
                token_pagination = None,
                visitor_id = ''
            )
        else:
            return VideoListResponse(
        )
        """

    def testVideoListResponse(self):
        """Test VideoListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
